richardview.built\_in\_widgets package
======================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   richardview.built_in_widgets.spiciness_widget
   richardview.built_in_widgets.title_widget

Module contents
---------------

.. automodule:: richardview.built_in_widgets
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
